==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Sprawozdanie.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypSprawozdania;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Sprawozdanie extends GenericDPSObject {
    /**
     * SPRAWOZDANIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SPRAWOZDANIE.DATA_WYGENEROWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWygenerowania;

    /**
     * SPRAWOZDANIE.KWARTAL
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kwartal;

    /**
     * SPRAWOZDANIE.NAZWA_PLIKU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwaPliku;

    /**
     * SPRAWOZDANIE.NUMER
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long numer;

    /**
     * SPRAWOZDANIE.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypSprawozdania typ;

    /**
     * SPRAWOZDANIE.ROK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer rok;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SPRAWOZDANIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SPRAWOZDANIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SPRAWOZDANIE.DATA_WYGENEROWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWygenerowania() {
        return dataWygenerowania;
    }

    /**
     * SPRAWOZDANIE.DATA_WYGENEROWANIA
     *
     * @param dataWygenerowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWygenerowania(Date dataWygenerowania) {
        this.dataWygenerowania = dataWygenerowania;
    }

    /**
     * @return SPRAWOZDANIE.KWARTAL
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKwartal() {
        return kwartal;
    }

    /**
     * SPRAWOZDANIE.KWARTAL
     *
     * @param kwartal
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwartal(Integer kwartal) {
        this.kwartal = kwartal;
    }

    /**
     * @return SPRAWOZDANIE.NAZWA_PLIKU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwaPliku() {
        return nazwaPliku;
    }

    /**
     * SPRAWOZDANIE.NAZWA_PLIKU
     *
     * @param nazwaPliku
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwaPliku(String nazwaPliku) {
        this.nazwaPliku = nazwaPliku == null ? null : nazwaPliku.trim();
    }

    /**
     * @return SPRAWOZDANIE.NUMER
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getNumer() {
        return numer;
    }

    /**
     * SPRAWOZDANIE.NUMER
     *
     * @param numer
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNumer(Long numer) {
        this.numer = numer;
    }

    /**
     * @return SPRAWOZDANIE.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypSprawozdania getTyp() {
        return typ;
    }

    /**
     * SPRAWOZDANIE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypSprawozdania typ) {
        this.typ = typ;
    }

    /**
     * @return SPRAWOZDANIE.ROK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * SPRAWOZDANIE.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Sprawozdanie other = (Sprawozdanie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataWygenerowania() == null ? other.getDataWygenerowania() == null : this.getDataWygenerowania().equals(other.getDataWygenerowania()))
            && (this.getKwartal() == null ? other.getKwartal() == null : this.getKwartal().equals(other.getKwartal()))
            && (this.getNazwaPliku() == null ? other.getNazwaPliku() == null : this.getNazwaPliku().equals(other.getNazwaPliku()))
            && (this.getNumer() == null ? other.getNumer() == null : this.getNumer().equals(other.getNumer()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataWygenerowania() == null) ? 0 : getDataWygenerowania().hashCode());
        result = prime * result + ((getKwartal() == null) ? 0 : getKwartal().hashCode());
        result = prime * result + ((getNazwaPliku() == null) ? 0 : getNazwaPliku().hashCode());
        result = prime * result + ((getNumer() == null) ? 0 : getNumer().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataWygenerowania=").append(dataWygenerowania);
        sb.append(", kwartal=").append(kwartal);
        sb.append(", nazwaPliku=").append(nazwaPliku);
        sb.append(", numer=").append(numer);
        sb.append(", typ=").append(typ);
        sb.append(", rok=").append(rok);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Sprawozdanie.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypSprawozdania;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Sprawozdanie extends GenericDPSObject {
    /**
     * SPRAWOZDANIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SPRAWOZDANIE.DATA_WYGENEROWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWygenerowania;

    /**
     * SPRAWOZDANIE.KWARTAL
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kwartal;

    /**
     * SPRAWOZDANIE.NAZWA_PLIKU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwaPliku;

    /**
     * SPRAWOZDANIE.NUMER
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long numer;

    /**
     * SPRAWOZDANIE.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypSprawozdania typ;

    /**
     * SPRAWOZDANIE.ROK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer rok;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SPRAWOZDANIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SPRAWOZDANIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SPRAWOZDANIE.DATA_WYGENEROWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWygenerowania() {
        return dataWygenerowania;
    }

    /**
     * SPRAWOZDANIE.DATA_WYGENEROWANIA
     *
     * @param dataWygenerowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWygenerowania(Date dataWygenerowania) {
        this.dataWygenerowania = dataWygenerowania;
    }

    /**
     * @return SPRAWOZDANIE.KWARTAL
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKwartal() {
        return kwartal;
    }

    /**
     * SPRAWOZDANIE.KWARTAL
     *
     * @param kwartal
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwartal(Integer kwartal) {
        this.kwartal = kwartal;
    }

    /**
     * @return SPRAWOZDANIE.NAZWA_PLIKU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwaPliku() {
        return nazwaPliku;
    }

    /**
     * SPRAWOZDANIE.NAZWA_PLIKU
     *
     * @param nazwaPliku
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwaPliku(String nazwaPliku) {
        this.nazwaPliku = nazwaPliku == null ? null : nazwaPliku.trim();
    }

    /**
     * @return SPRAWOZDANIE.NUMER
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getNumer() {
        return numer;
    }

    /**
     * SPRAWOZDANIE.NUMER
     *
     * @param numer
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNumer(Long numer) {
        this.numer = numer;
    }

    /**
     * @return SPRAWOZDANIE.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypSprawozdania getTyp() {
        return typ;
    }

    /**
     * SPRAWOZDANIE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypSprawozdania typ) {
        this.typ = typ;
    }

    /**
     * @return SPRAWOZDANIE.ROK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * SPRAWOZDANIE.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Sprawozdanie other = (Sprawozdanie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataWygenerowania() == null ? other.getDataWygenerowania() == null : this.getDataWygenerowania().equals(other.getDataWygenerowania()))
            && (this.getKwartal() == null ? other.getKwartal() == null : this.getKwartal().equals(other.getKwartal()))
            && (this.getNazwaPliku() == null ? other.getNazwaPliku() == null : this.getNazwaPliku().equals(other.getNazwaPliku()))
            && (this.getNumer() == null ? other.getNumer() == null : this.getNumer().equals(other.getNumer()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataWygenerowania() == null) ? 0 : getDataWygenerowania().hashCode());
        result = prime * result + ((getKwartal() == null) ? 0 : getKwartal().hashCode());
        result = prime * result + ((getNazwaPliku() == null) ? 0 : getNazwaPliku().hashCode());
        result = prime * result + ((getNumer() == null) ? 0 : getNumer().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataWygenerowania=").append(dataWygenerowania);
        sb.append(", kwartal=").append(kwartal);
        sb.append(", nazwaPliku=").append(nazwaPliku);
        sb.append(", numer=").append(numer);
        sb.append(", typ=").append(typ);
        sb.append(", rok=").append(rok);
        sb.append("]");
        return sb.toString();
    }
}
